@@ -1,7 +1,9 @@
 
-#' @importFrom replyr gapply
+
+#' @importFrom graphics hist
 NULL
 
+
 #' Plot two histograms conditioned on truthVar.
 #'
 #' @param frame data frame to get values from
@@ -26,8 +28,7 @@ DoubleHistogramPlot <- function(frame, xvar, truthVar, title, ...,
                                 breaks=40) {
   checkArgs(frame=frame,xvar=xvar,yvar=truthVar,title=title,...)
   if(!requireNamespace('graphics',quietly = TRUE)) {
-    warning("DoubleHistogramPlot needs graphics")
-    return(NULL)
+    return("WVPlots::DoubleHistogramPlot needs graphics")
   }
   count <- NULL # used as a symbol, declare not an unbound variable
   df <- data.frame(x=as.numeric(frame[[xvar]]),
@@ -37,7 +38,7 @@ DoubleHistogramPlot <- function(frame, xvar, truthVar, title, ...,
   yVals <- sort(unique(df[['y']]))
   signs <- (-1)^seq_len(length(yVals))
   names(signs) <- yVals
-  pf <- replyr::gapply(df,'y',
+  pf <- wv_gapply(df,'y',
                        partitionMethod='split',
                        function(sf) {
                          yGroup <- sf$y[[1]]
@@ -64,7 +65,7 @@ DoubleHistogramPlot <- function(frame, xvar, truthVar, title, ...,
   # display.brewer.all()
   palletName <- "Dark2"
   # build a net effect curve
-  netF <- replyr::gapply(pf,xvar,partitionMethod = 'split',
+  netF <- wv_gapply(pf,xvar,partitionMethod = 'split',
                          function(fi) {
                            di <- data.frame(count=sum(fi$count))
                            di[[xvar]] <- fi[[xvar]][[1]]
